<!DOCTYPE html>
<html lang="en">

<!-- Mirrored from seoc-html-v2.vercel.app/index11.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:40:12 GMT -->
<!-- Added by HTTrack --><meta http-equiv="content-type" content="text/html;charset=utf-8" /><!-- /Added by HTTrack -->
<head>
     <meta charset="UTF-8">
     <meta name="viewport" content="width=device-width, initial-scale=1.0">
     <title>SEOC - Digital Marketing Agency</title>

     <!--=====FAB ICON=======-->
    <link rel="shortcut icon" href="assets/img/logo/fav-logo1.png" type="image/x-icon">

    <!--===== CSS LINK =======-->
    <link rel="stylesheet" href="assets/css/plugins/bootstrap.min.css">
    <link rel="stylesheet" href="assets/css/plugins/aos.css">
    <link rel="stylesheet" href="assets/css/plugins/fontawesome.css">
    <link rel="stylesheet" href="assets/css/plugins/magnific-popup.css">
    <link rel="stylesheet" href="assets/css/plugins/mobile.css">
    <link rel="stylesheet" href="assets/css/plugins/owlcarousel.min.css">
    <link rel="stylesheet" href="assets/css/plugins/sidebar.css">
    <link rel="stylesheet" href="assets/css/plugins/slick-slider.css">
    <link rel="stylesheet" href="assets/css/plugins/nice-select.css">
    <link rel="stylesheet" href="assets/css/main.css">

    <!--=====  JS SCRIPT LINK =======-->
    <script src="assets/js/plugins/jquery-3-6-0.min.js"></script>
</head>
<body class="homepage11-body">

<!--===== PRELOADER STARTS =======-->
<div class="preloader preloader1">
  <div class="loading-container">
    <div class="loading"></div>
    <div id="loading-icon"><img src="assets/img/logo/preloader.png" alt=""></div>
  </div>
</div>
<!--===== PRELOADER ENDS =======-->

<!--===== PROGRESS STARTS=======-->
<div class="paginacontainer">
     <div class="progress-wrap">
       <svg class="progress-circle svg-content" width="100%" height="100%" viewBox="-1 -1 102 102">
         <path d="M50,1 a49,49 0 0,1 0,98 a49,49 0 0,1 0,-98"/>
       </svg>
     </div>
   </div>
 <!--===== PROGRESS ENDS=======-->

   <!--=====HEADER START=======-->
   <header class="homepage11-body">
    <div class="header-area homepage11 header header-sticky d-none d-lg-block " id="header">
      <div class="container">
        <div class="row">
          <div class="col-lg-12">
            <div class="header-elements">
              <div class="site-logo">
                <a href="index.html"><img src="assets/img/logo/logo2.png" alt=""></a>
              </div>
              <div class="main-menu">
                <ul>
                  <li><a href="#">Home <i class="fa-solid fa-angle-down"></i></a>
                    <div class="tp-submenu">
                      <div class="row">
                         <div class="col-lg-12">
                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img1.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index1.html" target="_blank">One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="404.html">SEO & Digital Marketing 01</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img2.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index2.html" target="_blank"> Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index2.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index2.html">SEO & Digital Marketing 02</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/comming-soon.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn18" href="index3.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn18" href="single-index3.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index3.html">SEO & Digital Marketing 03</a>
                               </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img3.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index4.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index4.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index4.html">SEO & Digital Marketing 04</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img4.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index5.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index5.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index5.html">SEO & Digital Marketing 05</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img11.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index11.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index11.html" target="_blank">One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index11.html">Staffing Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img12.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index12.html" target="_blank"> Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index12.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index12.html">Consulting Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img13.png" alt="" class="commingsoon">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn18" href="index13.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn18" href="single-index13.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index13.html">Advertising Agency</a>
                               </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img14.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index14.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index14.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index14.html">IT Solution Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img15.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>NEW</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index15.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index15.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index15.html">Startup Agency</a>
                                 </div>
                              </div>
                              <div class="space20"></div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img5.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index6.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index6.html" target="_blank">One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index6.html">SEO & Digital Marketing 06</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img6.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index7.html" target="_blank"> Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index7.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index7.html">SEO & Digital Marketing 07</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img7.png" alt="" class="commingsoon">
                                </div>
                                <div class="homemenu-btn">
                                  <a class="header-btn18" href="index8.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                  <div class="space16"></div>
                                  <a class="header-btn18" href="single-index8.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                               </div>
                               <div class="homemenu-content">
                                <a href="index8.html">SEO & Digital Marketing 08</a>
                               </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img8.png" alt="">
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index9.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index9.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index9.html">SEO & Digital Marketing 09</a>
                                 </div>
                              </div>
                            </div>

                            <div class="images">
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1">
                                <img src="assets/img/all-images/demo-img9.png" alt="">
                                </div>
                                <div class="text">
                                  <h2>HOT</h2>
                                </div>
                                 <div class="homemenu-btn">
                                    <a class="header-btn18" href="index10.html" target="_blank">Multi Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                    <div class="space16"></div>
                                    <a class="header-btn18" href="single-index10.html" target="_blank"> One Page <span><i class="fa-solid fa-arrow-right"></i></span></a>
                                 </div>
                                 <div class="homemenu-content">
                                  <a href="index10.html">SEO & Digital Marketing 10</a>
                                 </div>
                              </div>
                            </div>
                          </div>

                          <div class="all-images-menu">
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img17.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index6.html">Creative Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img16.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index7.html">Digital Marketing Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img18.png" alt="" class="commingsoon">
                                </div>
                               <div class="homemenu-content">
                                <a href="index8.html">Digital Marketer Agency</a>
                               </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img19.png" alt="">
                                </div>
  
                                 <div class="homemenu-content">
                                  <a href="index9.html">Corporate Agency</a>
                                 </div>
                              </div>
                            </div>
  
                            <div class="images">
                              <div class="space20"></div>
                              <div class="homemenu-thumb" style="margin: 0;">
                                <div class="img1 comming-soon">
                                <img src="assets/img/all-images/demo-img20.png" alt="">
                                </div>
                                 <div class="homemenu-content">
                                  <a href="index10.html">Coming Soon</a>
                                 </div>
                              </div>
                            </div>
                          </div>
                         </div>
                      </div>
                   </div>
                  </li>
                  <li><a href="about.html">About</a></li>
                  <li><a href="#">Services <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="service1.html">Service One</a></li>
                      <li><a href="service2.html">Service Two</a></li>
                      <li><a href="service3.html">Service Three</a></li>
                      <li><a href="service4.html">Service Four</a></li>
                      <li><a href="service5.html">Service Five</a></li>
                    </ul>
                  </li>
                  <li><a href="#">Blogs <i class="fa-solid fa-angle-down"></i></a>
                  <ul class="dropdown-padding">
                    <li><a href="blog.html">Blog One</a></li>
                    <li><a href="blog-left.html">Blog Left</a></li>
                    <li><a href="blog-right.html">Blog Right</a></li>
                    <li><a href="blog-single.html">Blog Single</a></li>
                  </ul>
                  </li>
                  <li><a href="#">Pages <i class="fa-solid fa-angle-down"></i></a>
                    <ul class="dropdown-padding">
                      <li><a href="case.html">Case Study</a></li>
                      <li><a href="case-single.html">Case Study Single</a></li>
                      <li><a href="team.html">Our Team</a></li>
                      <li><a href="pricing.html">Pricing Plan</a></li>
                      <li><a href="testimonials.html">Testimonials</a></li>
                      <li><a href="faq.html">FAQ</a></li>
                      <li><a href="404-2.html">404</a></li>
                    </ul>
                  </li>
                  <li><a href="contact.html">Contact Us</a></li>
                </ul>
              </div>
              <div class="btn-area">
                <a href="contact.html" class="header-btn18">Get Started <i class="fa-solid fa-arrow-right"></i></a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </header>
  <!--=====HEADER END =======-->

  <!--===== MOBILE HEADER STARTS =======-->
 <div class="mobile-header mobile-haeder11 d-block d-lg-none">
  <div class="container-fluid">
    <div class="col-12">
      <div class="mobile-header-elements">
        <div class="mobile-logo">
          <a href="index.html"><img src="assets/img/logo/logo12.png" alt=""></a>
        </div>
        <div class="mobile-nav-icon dots-menu">
          <i class="fa-solid fa-bars"></i>
        </div>
      </div>
    </div>
  </div>
</div>

<div class="mobile-sidebar mobile-sidebar11">
  <div class="logosicon-area">
    <div class="logos">
      <img src="assets/img/logo/logo12.png" alt="">
    </div>
    <div class="menu-close">
      <i class="fa-solid fa-xmark"></i>
    </div>
   </div>
  <div class="mobile-nav mobile-nav1">
    <ul class="mobile-nav-list nav-list1">
      <li><a href="#" >Home </a>
        <ul class="sub-menu">
          <li>
            <a href="#">Multiple Page</a>
            <ul class="sub-menu">
              <li><a href="index.html">Home One</a></li>
              <li><a href="index2.html">Home Two</a></li>
              <li><a href="index3.html">Home Three</a></li>
              <li><a href="index4.html">Home Four</a></li>
              <li><a href="index5.html">Home Five</a></li>
              <li><a href="index6.html">Home Six</a></li>
              <li><a href="index7.html">Home Seven</a></li>
              <li><a href="index8.html">Home Eight</a></li>
              <li><a href="index9.html">Home Nine</a></li>
              <li><a href="index10.html">Home Ten</a></li>
              <li><a href="index11.html">Home Eleven</a></li>
              <li><a href="index12.html">Home Twelve</a></li>
              <li><a href="index13.html">Home Thirteen</a></li>
              <li><a href="index14.html">Home Fouteen</a></li>
              <li><a href="index15.html">Home Fifteen</a></li>
            </ul>
          </li>
          <li>
            <a href="#">Landing Page</a>
            <ul class="sub-menu">
              <li><a href="single-index1.html" target="_blank">Home One</a></li>
              <li><a href="single-index2.html" target="_blank">Home Two</a></li>
              <li><a href="single-index3.html" target="_blank">Home Three</a></li>
              <li><a href="single-index4.html" target="_blank">Home Four</a></li>
              <li><a href="single-index5.html" target="_blank">Home Five</a></li>
              <li><a href="single-index6.html" target="_blank">Home Six</a></li>
              <li><a href="single-index7.html" target="_blank">Home Seven</a></li>
              <li><a href="single-index8.html" target="_blank">Home Eight</a></li>
              <li><a href="single-index9.html" target="_blank">Home Nine</a></li>
              <li><a href="single-index10.html" target="_blank">Home Ten</a></li>
              <li><a href="single-index11.html" target="_blank">Home Eleven</a></li>
              <li><a href="single-index12.html" target="_blank">Home Twelve</a></li>
              <li><a href="single-index13.html" target="_blank">Home Thirteen</a></li>
              <li><a href="single-index14.html" target="_blank">Home Fouteen</a></li>
              <li><a href="single-index15.html" target="_blank">Home Fifteen</a></li>
            </ul>
          </li>
        </ul>
      </li>
      <li><a href="about.html">About</a></li>
      <li><a href="404-3.html">Services</a>
        <ul class="sub-menu">
          <li><a href="service1.html">Service One</a></li>
          <li><a href="service2.html">Service Two</a></li>
          <li><a href="service3.html">Service Three</a></li>
          <li><a href="service4.html">Service Four</a></li>
          <li><a href="service5.html">Service Five</a></li>
        </ul>
      </li>
      <li><a href="#">Blogs</a>
        <ul class="sub-menu">
          <li><a href="blog.html">Blog One</a></li>
          <li><a href="blog-left.html">Blog Left</a></li>
          <li><a href="blog-right.html">Blog Right</a></li>
          <li><a href="blog-single.html">Blog Single</a></li>
        </ul>
      </li>
      <li><a href="#">Pages</a>
        <ul class="sub-menu">
          <li><a href="case.html">Case Study One</a></li>
          <li><a href="case-single.html">Case Study Single</a></li>
          <li><a href="team.html">Our Team</a></li>
          <li><a href="pricing.html">Pricing Plan</a></li>
          <li><a href="testimonials.html">Testimonials</a></li>
          <li><a href="faq.html">FAQ</a></li>
          <li><a href="404-2.html">404</a></li>
        </ul>
      </li>
      <li><a href="contact.html">Contact Us</a></li>
    </ul>

    <div class="allmobilesection">
      <a href="contact.html"  class="header-btn18">Get Started <span><i class="fa-solid fa-arrow-right"></i></span></a>
      <div class="single-footer">
        <h3>Contact Info</h3>
        <div class="footer1-contact-info">
          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-phone-volume"></i>
            </div>
            <div class="contact-info-text">
              <a href="tel:+3(924)4596512">+3(924)4596512</a>
            </div>
          </div>

          <div class="contact-info-single">
            <div class="contact-info-icon">
              <i class="fa-solid fa-envelope"></i>
            </div>
            <div class="contact-info-text">
              <a href="mailto:info@example.com">info@example.com</a>
            </div>
          </div>

          <div class="single-footer">
            <h3>Our Location</h3>
            
            <div class="contact-info-single">
              <div class="contact-info-icon">
                <i class="fa-solid fa-location-dot"></i>
              </div>
              <div class="contact-info-text">
                <a href="mailto:info@example.com" >55 East Birchwood Ave.Brooklyn, <br> New York 11201,United States</a>
              </div>
            </div>

          </div>
          <div class="single-footer">
            <h3>Social Links</h3>
            
            <div class="social-links-mobile-menu">
              <ul>
                <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
              </ul>
            </div>
          </div>
        </div>
      </div>
     </div>
  </div>
</div>
<!--===== MOBILE HEADER STARTS =======-->

<!--===== HERO AREA STARTS =======-->
<div class="hero11-section-area">
    <img src="assets/img/elements/elements22.png" alt="" class="elements22 aniamtion-key-1">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-5">
                <div class="hero-header">
                    <h5 data-aos="fade-left" data-aos-duration="800"><img src="assets/img/icons/logo-icons2.svg" alt="">Where Talent Meets Opportunity</h5>
                    <div class="space24"></div>
                    <h1 class="text-anime-style-3">Tailored Staffing Solutions for the Finance Industry</h1>
                    <div class="space16"></div>
                    <p data-aos="fade-left" data-aos-duration="1000">We are dedicated connecting businesses with the industry’s most tailgating accounting and finance.</p>
                    <div class="space32"></div>
                    <div class="btn-area" data-aos="fade-left" data-aos-duration="1200">
                        <a href="contact.html" class="header-btn18">Schedule A Consultation <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>
            <div class="col-lg-1"></div>
            <div class="col-lg-6">
                <div class="images">
                    <div class="img reveal"> 
                        <img src="assets/img/all-images/new-img/header-img11.png" alt="">
                    </div>
                    <img src="assets/img/elements/elements21.png" alt="" class="elements21">
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== HERO AREA ENDS =======-->
<div class="space100 d-lg-block d-none"></div>
<div class="others11-section-area">
  <div class="container">
    <div class="row">
      <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="800">
        <div class="others-boxarea">
          <h3>Hotel</h3>
          <div class="space16"></div>
          <a href="#"><img src="assets/img/icons/user1.svg" alt=""> 2344 Staffs</a>
        </div>
      </div>
      <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="900">
        <div class="others-boxarea">
          <h3>hospitality</h3>
          <div class="space16"></div>
          <a href="#"><img src="assets/img/icons/user1.svg" alt=""> 7576 Staffs</a>
        </div>
      </div>
      <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
        <div class="others-boxarea">
          <h3>Kitchen</h3>
          <div class="space16"></div>
          <a href="#"><img src="assets/img/icons/user1.svg" alt=""> 8968 Staffs</a>
        </div>
      </div>

      <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1100">
        <div class="others-boxarea">
          <h3>retail</h3>
          <div class="space16"></div>
          <a href="#"><img src="assets/img/icons/user1.svg" alt=""> 2344 Staffs</a>
        </div>
      </div>

      <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
        <div class="others-boxarea">
          <h3>events</h3>
          <div class="space16"></div>
          <a href="#"><img src="assets/img/icons/user1.svg" alt=""> 3234 Staffs</a>
        </div>
      </div>

      <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="900">
        <div class="others-boxarea">
          <h3>labor</h3>
          <div class="space16"></div>
          <a href="#"><img src="assets/img/icons/user1.svg" alt=""> 7521 Staffs</a>
        </div>
      </div>

      <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
        <div class="others-boxarea">
          <h3>driving</h3>
          <div class="space16"></div>
          <a href="#"><img src="assets/img/icons/user1.svg" alt=""> 5432 Staffs</a>
        </div>
      </div>

      <div class="col-lg-3 col-md-6" data-aos="zoom-in" data-aos-duration="1100">
        <div class="others-boxarea">
          <h3>caretaker</h3>
          <div class="space16"></div>
          <a href="#"><img src="assets/img/icons/user1.svg" alt=""> 2344 Staffs</a>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== ABOUT AREA STARTS =======-->
<div class="about11-section-area sp1">
  <div class="container">
    <div class="row align-items-center">
      <div class="col-lg-6">
        <div class="about-images-area">
          <div class="row align-items-center">
            <div class="col-lg-6 col-md-6">
              <div class="img1 reveal image-anime">
                <img src="assets/img/all-images/new-img/about11-img1.png" alt="">
              </div>
              <div class="space30 d-md-none d-block"></div>
            </div>
            <div class="col-lg-6 col-md-6">
              <div class="img1 reveal image-anime">
                <img src="assets/img/all-images/new-img/about11-img2.png" alt="">
              </div>
              <div class="space30"></div>
              <div class="img1 reveal image-anime">
                <img src="assets/img/all-images/new-img/about11-img3.png" alt="">
              </div>
            </div>
          </div>
        </div>
      </div>

      <div class="col-lg-6">
        <div class="about11-header heading16">
          <h5 data-aos="fade-left" data-aos-duration="800"><img src="assets/img/icons/logo-icon8.svg" alt="">About SEOC</h5>
          <div class="space24"></div>
          <h2 class="text-anime-style-3">Elevate Your Workforce, Elevate Best Business</h2>
          <div class="space16"></div>
          <p data-aos="fade-left" data-aos-duration="1000">At SEOC, we understand that key to business success lies in having the right people on your team. That's why we're committed to connecting you with top-tier talent.</p>
          <div class="space8"></div>
          <div class="row" data-aos="fade-left" data-aos-duration="1100">
            <div class="col-lg-7">
              <ul>
                <li><img src="assets/img/icons/check14.svg" alt=""> Tailored Staffing Solutions</li>
                <li><img src="assets/img/icons/check14.svg" alt=""> Streamlined Hiring Process</li>
              </ul>
            </div>
            <div class="col-lg-5">
              <ul>
                <li><img src="assets/img/icons/check14.svg" alt=""> Ongoing Support</li>
                <li><img src="assets/img/icons/check14.svg" alt=""> Experience Team</li>
              </ul>
            </div>
          </div>
          <div class="space32"></div>
          <div class="btn-area1" data-aos="fade-left" data-aos-duration="1200">
            <a href="contact.html" class="header-btn19">Join Our Network <i class="fa-solid fa-arrow-right"></i></a>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== ABOUT AREA ENDS =======-->

<!--===== SERVICE AREA STARTS =======-->
<div class="service11-section-area sp1">
  <div class="container">
    <div class="row">
      <div class="col-lg-6 m-auto">
        <div class="service11-header text-center heading16 space-margin60">
          <h5><img src="assets/img/icons/logo-icon8.svg" alt=""> INDUSTRIUS SERVED</h5>
          <div class="space24"></div>
          <h2 class="text-anime-style-3">Our Specialized Industries</h2>
        </div>
      </div>
    </div>
    <div class="row">
      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
        <div class="service11-boxarea">
          <div class="img1">
            <img src="assets/img/all-images/new-img/service11-img1.png" alt="">
          </div>
          <div class="content-area">
            <div class="icons">
              <img src="assets/img/icons/service-icon23.svg" alt="">
            </div>
            <a href="service1.html">Accounting Finance</a>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
        <div class="service11-boxarea">
          <div class="img1">
            <img src="assets/img/all-images/new-img/service11-img2.png" alt="">
          </div>
          <div class="content-area">
            <div class="icons">
              <img src="assets/img/icons/service-icon24.svg" alt="">
            </div>
            <a href="service1.html">Digital Marketing</a>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
        <div class="service11-boxarea">
          <div class="img1">
            <img src="assets/img/all-images/new-img/service11-img3.png" alt="">
          </div>
          <div class="content-area">
            <div class="icons">
              <img src="assets/img/icons/service-icon25.svg" alt="">
            </div>
            <a href="service1.html">Business Consulting</a>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
        <div class="service11-boxarea">
          <div class="img1">
            <img src="assets/img/all-images/new-img/service11-img4.png" alt="">
          </div>
          <div class="content-area">
            <div class="icons">
              <img src="assets/img/icons/service-icon26.svg" alt="">
            </div>
            <a href="service1.html">Technology Services</a>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
        <div class="service11-boxarea">
          <div class="img1">
            <img src="assets/img/all-images/new-img/service11-img5.png" alt="">
          </div>
          <div class="content-area">
            <div class="icons">
              <img src="assets/img/icons/service-icon27.svg" alt="">
            </div>
            <a href="service1.html">Logistics Services</a>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
        <div class="service11-boxarea">
          <div class="img1">
            <img src="assets/img/all-images/new-img/service11-img6.png" alt="">
          </div>
          <div class="content-area">
            <div class="icons">
              <img src="assets/img/icons/service-icon28.svg" alt="">
            </div>
            <a href="service1.html">Front Line Support</a>
          </div>
        </div>
      </div>
      <div class="col-lg-12 text-center">
        <div class="space30"></div>
        <div class="btn-area text-center"><a href="service1.html" class="service-btn1">View More Services <i class="fa-solid fa-arrow-right"></i></a></div>
      </div>
    </div>
  </div>
</div>
<!--===== SERVICE AREA ENDS =======-->

<!--===== WORK AREA STARTS =======-->
<div class="work11-section-area sp2">
  <div class="container">
    <div class="row">
      <div class="col-lg-6 m-auto">
        <div class="work11-header text-center heading16 space-margin60">
          <h5><img src="assets/img/icons/logo-icon8.svg" alt="">How It Works</h5>
          <div class="space24"></div>
          <h2 class="text-anime-style-3">Simple Staffing Procedures</h2>
        </div>
      </div>
    </div>
    <div class="row">
      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
        <div class="work11-boxarea">
          <img src="assets/img/elements/elements23.png" alt="" class="elements23">
          <div class="icons">
            <img src="assets/img/icons/work-icon10.svg" alt="">
          </div>
          <div class="space24"></div>
          <div class="textarea">
            <a href="service1.html">Job Analysis</a>
            <div class="space16"></div>
            <p>Job analysis is a critical process <br class="d-lg-block d-none"> understanding defining specific.</p>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
        <div class="work11-boxarea">
          <img src="assets/img/elements/elements24.png" alt="" class="elements24">
          <div class="icons">
            <img src="assets/img/icons/work-icon11.svg" alt="">
          </div>
          <div class="space24"></div>
          <div class="textarea">
            <a href="service1.html">Applicant Review</a>
            <div class="space16"></div>
            <p>The applicant review process <br class="d-lg-block d-none"> is  vital step in ensuring that only.</p>
          </div>
        </div>
      </div>

      <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
        <div class="work11-boxarea">
          <div class="icons">
            <img src="assets/img/icons/work-icon12.svg" alt="">
          </div>
          <div class="space24"></div>
          <div class="textarea">
            <a href="service1.html">Job Place Check</a>
            <div class="space16"></div>
            <p>Job Place Check is an essential <br class="d-lg-block d-none"> component our best SEOC.</p>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== WORK AREA ENDS =======-->

<!--===== CASE AREA STARTS =======-->
<div class="case10-section-area sp1">
  <div class="container">
    <div class="row">
      <div class="col-lg-5">
        <div class="case-header space-margin60 heading16">
          <h5><img src="assets/img/icons/logo-icon8.svg" alt=""> Case Studies</h5>
          <div class="space24"></div>
          <h2 class="text-anime-style-3">Our Success All Project</h2>
        </div>
      </div>
    </div>
    <div class="row">
      <div class="col-lg-12">
        <div class="case-slider-area owl-carousel">
          <div class="case11-boxarea">
            <div class="img1 image-anime">
              <img src="assets/img/all-images/new-img/case-img1-h11.png" alt="">
            </div>
            <div class="text-area">
              <p>staffing solution</p>
              <div class="space16"></div>
              <a href="case-single.html">Real-World Staffing Solutions</a>
              <div class="arrow">
                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
              </div>
            </div>
          </div>

          <div class="case11-boxarea">
            <div class="img1 image-anime">
              <img src="assets/img/all-images/new-img/case-img2-h11.png" alt="">
            </div>
            <div class="text-area">
              <p>staffing success</p>
              <div class="space16"></div>
              <a href="case-single.html">Client Success Highlights</a>
              <div class="arrow">
                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
              </div>
            </div>
          </div>

          <div class="case11-boxarea">
            <div class="img1 image-anime">
              <img src="assets/img/all-images/new-img/case-img3-h11.png" alt="">
            </div>
            <div class="text-area">
              <p>staffing Challenge</p>
              <div class="space16"></div>
              <a href="case-single.html">Transforming Challenges Into</a>
              <div class="arrow">
                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
              </div>
            </div>
          </div>

          <div class="case11-boxarea">
            <div class="img1 image-anime">
              <img src="assets/img/all-images/new-img/case-img1-h11.png" alt="">
            </div>
            <div class="text-area">
              <p>staffing solution</p>
              <div class="space16"></div>
              <a href="case-single.html">Real-World Staffing Solutions</a>
              <div class="arrow">
                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
              </div>
            </div>
          </div>

          <div class="case11-boxarea">
            <div class="img1 image-anime">
              <img src="assets/img/all-images/new-img/case-img2-h11.png" alt="">
            </div>
            <div class="text-area">
              <p>staffing success</p>
              <div class="space16"></div>
              <a href="case-single.html">Client Success Highlights</a>
              <div class="arrow">
                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
              </div>
            </div>
          </div>

          <div class="case11-boxarea">
            <div class="img1 image-anime">
              <img src="assets/img/all-images/new-img/case-img3-h11.png" alt="">
            </div>
            <div class="text-area">
              <p>staffing Challenge</p>
              <div class="space16"></div>
              <a href="case-single.html">Transforming Challenges Into</a>
              <div class="arrow">
                <a href="case-single.html"><i class="fa-solid fa-arrow-right"></i></a>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== CASE AREA ENDS =======-->

<!--===== TEAM AREA STARTS =======-->
<div class="team11-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-7 m-auto">
                <div class="team-header text-center heading16 space-margin60">
                    <h5><img src="assets/img/icons/logo-icon8.svg" alt=""> Our Team</h5>
                    <div class="space24"></div>
                    <h2 class="text-anime-style-3">Get to Know Our Professionals</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                <div class="team11-boxarea">
                    <div class="img1 image-anime">
                        <img src="assets/img/all-images/new-img/team11-h11.png" alt="">
                    </div>
                    <div class="content-area">
                        <div class="text">
                            <a href="team.html">SR. Alex Robertson</a>
                            <div class="space12"></div>
                            <p>Founder, Analysts</p>
                        </div>
                        <div class="icons">
                            <a href="#"><i class="fa-solid fa-share-nodes"></i></a>
                        </div>
                    </div>
                    <ul>
                      <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                      <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                      <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>                      
                      <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                    </ul>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
              <div class="team11-boxarea">
                  <div class="img1 image-anime">
                      <img src="assets/img/all-images/new-img/team12-h11.png" alt="">
                  </div>
                  <div class="content-area">
                      <div class="text">
                          <a href="team.html">Devin Romaguera</a>
                          <div class="space12"></div>
                          <p>Senior Consultant</p>
                      </div>
                      <div class="icons">
                          <a href="#"><i class="fa-solid fa-share-nodes"></i></a>
                      </div>
                  </div>
                  <ul>
                    <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                    <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                    <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>                      
                    <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                  </ul>
              </div>
          </div>

          <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
            <div class="team11-boxarea">
                <div class="img1 image-anime">
                    <img src="assets/img/all-images/new-img/team13-h11.png" alt="">
                </div>
                <div class="content-area">
                    <div class="text">
                        <a href="team.html">Shelia Abernathy</a>
                        <div class="space12"></div>
                        <p>CEO Of Finance</p>
                    </div>
                    <div class="icons">
                        <a href="#"><i class="fa-solid fa-share-nodes"></i></a>
                    </div>
                </div>
                <ul>
                  <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                  <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                  <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>                      
                  <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                </ul>
            </div>
        </div>
        </div>
    </div>
</div>
<!--===== TEAM AREA ENDS =======-->

<!--===== BLOG AREA STARTS =======-->
<div class="blog11-section-area sp2">
    <div class="container">
        <div class="row">
            <div class="col-lg-6 m-auto">
                <div class="blog-header heading16 space-margin60 text-center">
                    <h5><img src="assets/img/icons/logo-icon8.svg" alt=""> Our Blog</h5>
                    <div class="space24"></div>
                    <h2 class="text-anime-style-3">Our Latest Blog & News</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="800">
                <div class="blog11-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/blog-img11-h11.png" alt="">
                    </div>
                    <div class="content-area">
                        <ul>
                            <li><i class="fa-regular fa-calendar-days"></i> 8 December 2024</li>
                        </ul>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="head">How To Create An Recruitment Strategy For Your Business</a>
                        <div class="space24"></div>
                        <a href="blog-single.html" class="readmore">learn more <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1000">
                <div class="blog11-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/blog-img12-h11.png" alt="">
                    </div>
                    <div class="content-area">
                        <ul>
                            <li><i class="fa-regular fa-calendar-days"></i> 6 December 2024</li>
                        </ul>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="head">Navigating the Challenges of Remote Work Recruitment</a>
                        <div class="space24"></div>
                        <a href="blog-single.html" class="readmore">learn more <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>

            <div class="col-lg-4 col-md-6" data-aos="zoom-in" data-aos-duration="1200">
                <div class="blog11-boxarea">
                    <div class="img1">
                        <img src="assets/img/all-images/new-img/blog-img13-h11.png" alt="">
                    </div>
                    <div class="content-area">
                        <ul>
                            <li><i class="fa-regular fa-calendar-days"></i> 10 December 2024</li>
                        </ul>
                        <div class="space16"></div>
                        <a href="blog-single.html" class="head">How Retain In Talent: Strategies for Employee Engagement</a>
                        <div class="space24"></div>
                        <a href="blog-single.html" class="readmore">learn more <i class="fa-solid fa-arrow-right"></i></a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== BLOG AREA ENDS =======-->

<!--===== CONTACT AREA STARTS =======-->
<div class="contact11-section-area sp1">
    <div class="container">
        <div class="row">
            <div class="col-lg-6 m-auto">
                <div class="contact-header heading16 text-center space-margin60">
                    <h5><img src="assets/img/icons/logo-icon8.svg" alt=""> Contact Us Now</h5>
                    <div class="space24"></div>
                    <h2 class="text-anime-style-3">Let's Start The Conversation</h2>
                </div>
            </div>
        </div>
        <div class="row">
            <div class="col-lg-6" data-aos="fade-right" data-aos-duration="1000">
                <div class="contact-boxarea">
                    <h3>Send Us A Message</h3>
                    <div class="space16"></div>
                    <p>Our response time is within 30 minutes during business hours</p>
                    <div class="space8"></div>
                    <div class="row">
                        <div class="col-lg-6">
                            <div class="input-area">
                                <input type="text" placeholder="First Name">
                            </div>
                        </div>

                        <div class="col-lg-6">
                            <div class="input-area">
                                <input type="text" placeholder="Last Name">
                            </div>
                        </div>

                        <div class="col-lg-6">
                            <div class="input-area">
                                <input type="number" placeholder="Phone Number">
                            </div>
                        </div>

                        <div class="col-lg-6">
                            <div class="input-area">
                                <input type="email" placeholder="Email Address">
                            </div>
                        </div>

                        <div class="col-lg-12">
                            <div class="input-area">
                                <select name="country" id="country" class="country-area nice-select6">
                                    <option value="1" data-display="Service Type">Service Type</option>
                                    <option value="">Belgium</option>
                                    <option value="">Brezil</option>
                                    <option value="">Argentina</option>
                                    <option value="">Bangladesh</option>
                                    <option value="">Germany</option>
                                  </select>
                            </div>
                        </div>

                        <div class="col-lg-12">
                            <div class="input-area">
                                <textarea name="#" id="#" placeholder="Message"></textarea>
                            </div>
                        </div>
                        <div class="space32"></div>
                        <div class="col-lg-12">
                            <div class="input-area text-end">
                               <button type="submit">Submit Now <i class="fa-solid fa-arrow-right"></i></button>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-lg-6" data-aos="fade-left" data-aos-duration="1000">
                <div class="mapouter">
                    <div class="gmap_canvas">
                      <iframe src="https://www.google.com/maps/embed?pb=!1m14!1m12!1m3!1d4506257.120552435!2d88.67021924228865!3d21.954385721237916!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!5e0!3m2!1sen!2sbd!4v1704088968016!5m2!1sen!2sbd" width="600" height="450" style="border:0;" allowfullscreen="" loading="lazy" referrerpolicy="no-referrer-when-downgrade"></iframe>
                    </div>
                  </div>
            </div>
        </div>
    </div>
</div>
<!--===== CONTACT AREA ENDS =======-->

<!--===== CTA AREA STARTS =======-->
<div class="cta11-section-area sp4">
    <div class="container">
        <div class="row align-items-center">
            <div class="col-lg-5">
                <div class="cta-header">
                    <h2 class="text-anime-style-3">Ready To Power Up Your Savings And Reliability?</h2>
                    <div class="space32"></div>
                    <form>
                        <input type="text" placeholder="Your Email Address">
                        <button type="submit">Subscribe <i class="fa-solid fa-arrow-right"></i></button>
                    </form>
                </div>
            </div>
            <div class="col-lg-1"></div>
            <div class="col-lg-3 col-md-6">
                <div class="cta-box">
                    <div class="icon">
                        <img src="assets/img/icons/phone4.svg" alt="">
                    </div>
                    <div class="text">
                        <p>Call Us 24/7</p>
                        <div class="space14"></div>
                        <a href="tel:+1234567890"> +123 456 7890</a>
                    </div>
                </div>
            </div>

            <div class="col-lg-3 col-md-6">
                <div class="space30 d-md-none d-block"></div>
                <div class="cta-box">
                    <div class="icon">
                        <img src="assets/img/icons/email4.svg" alt="">
                    </div>
                    <div class="text">
                        <p>Mail Us Anytime</p>
                        <div class="space14"></div>
                        <a href="mailto:SEOC@gmail.com">SEOC@gmail.com</a>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>
<!--===== CTA AREA ENDS =======-->

<!--===== FOOTER AREA STARTS =======-->
<div class="footer11-section-area">
  <div class="container">
    <div class="row">
        <div class="col-lg-3 col-md-6">
            <div class="footer-log-area">
                <img src="assets/img/logo/logo12.png" alt="">
                <div class="space24"></div>
                <p>Our goal is to demystify the process, address your concerns, and empower you with the knowledge to embark.</p>
                <div class="space24"></div>
                <ul>
                    <li><a href="#"><i class="fa-brands fa-facebook-f"></i></a></li>
                    <li><a href="#"><i class="fa-brands fa-instagram"></i></a></li>
                    <li><a href="#"><i class="fa-brands fa-linkedin-in"></i></a></li>
                    <li><a href="#"><i class="fa-brands fa-youtube"></i></a></li>
                </ul>
            </div>
        </div>
        <div class="col-lg-3 col-md-6">
            <div class="space30 d-md-none d-block"></div>
            <div class="footer-content-area footer1">
                <h3>Quick Links</h3>
                <ul>
                    <li><a href="about.html">About Us</a></li>
                    <li><a href="service1.html">Our Services</a></li>
                    <li><a href="service2.html">Our Solution</a></li>
                    <li><a href="blog.html">Our Blog</a></li>
                    <li><a href="contact.html">Contact Us</a></li>
                </ul>
            </div>
        </div>
        <div class="col-lg-3 col-md-6">
            <div class="space30 d-lg-none d-block"></div>
            <div class="footer-content-area">
                <h3>Our Services</h3>
                <ul>
                    <li><a href="about.html">Accounting Finance</a></li>
                    <li><a href="service1.html">Business Consulting</a></li>
                    <li><a href="service2.html">Technology Services</a></li>
                    <li><a href="blog.html">Logistics Services</a></li>
                    <li><a href="contact.html">Front Line Support</a></li>
                </ul>
            </div>
        </div>
        <div class="col-lg-3 col-md-6">
            <div class="space30 d-lg-none d-block"></div>
            <div class="footer-contact-area">
                <h3>Contact Us</h3>
                <div class="icons-area">
                    <div class="icons">
                        <i class="fa-solid fa-phone-volume"></i>
                    </div>
                    <div class="text">
                        <a href="tel:+11234567890">+1 123 456 7890</a>
                    </div>
                </div>

                <div class="icons-area">
                    <div class="icons">
                        <i class="fa-solid fa-location-dot"></i>
                    </div>
                    <div class="text">
                        <a href="tel:+11234567890">421 Allen, Mexico 4233</a>
                    </div>
                </div>

                <div class="icons-area">
                    <div class="icons">
                        <i class="fa-solid fa-envelope"></i>
                    </div>
                    <div class="text">
                        <a href="mailto:seocstaffngagency@com">seocstaffngagency@com</a>
                    </div>
                </div>

                <div class="icons-area">
                    <div class="icons">
                        <i class="fa-solid fa-globe"></i>
                    </div>
                    <div class="text">
                        <a href="mailto:seocstaffngagency@com">seocstaffngagency@com</a>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <div class="space80 d-lg-block d-none"></div>
    <div class="space40 d-lg-none d-block"></div>
    <div class="row">
      <div class="col-lg-12">
        <div class="copyright-area">
          <div class="pera">
            <p>ⓒCopyright 2024 SEOC . All rights reserved</p>
          </div>
        </div>
      </div>
    </div>
  </div>
</div>
<!--===== FOOTER AREA ENDS =======-->


<!--===== JS SCRIPT LINK =======-->
<script src="assets/js/plugins/bootstrap.min.js"></script>
<script src="assets/js/plugins/fontawesome.js"></script>
<script src="assets/js/plugins/aos.js"></script>
<script src="assets/js/plugins/counter.js"></script>
<script src="assets/js/plugins/gsap.min.js"></script>
<script src="assets/js/plugins/ScrollTrigger.min.js"></script>
<script src="assets/js/plugins/Splitetext.js"></script>
<script src="assets/js/plugins/sidebar.js"></script>
<script src="assets/js/plugins/magnific-popup.js"></script>
<script src="assets/js/plugins/mobilemenu.js"></script>
<script src="assets/js/plugins/owlcarousel.min.js"></script>
<script src="assets/js/plugins/gsap-animation.js"></script>
<script src="assets/js/plugins/nice-select.js"></script>
<script src="assets/js/plugins/waypoints.js"></script>
<script src="assets/js/plugins/slick-slider.js"></script>
<script src="assets/js/plugins/circle-progress.js"></script>
<script src="assets/js/main.js"></script>

</body>

<!-- Mirrored from seoc-html-v2.vercel.app/index11.html by HTTrack Website Copier/3.x [XR&CO'2014], Wed, 12 Mar 2025 15:40:31 GMT -->
</html>